#include <iostream>
#include <exception>
#include <string>
#include <queue>
#include <set>
using namespace std;

#define BOARD_HEIGHT 15
#define BOARD_WIDTH 15

class invalid_movement: public exception {
public:
	virtual const char * what() const throw() {
		return "Invalid movement.";
	}
};

class snapshot {
private:
	const snapshot * parent;
	char board[BOARD_HEIGHT][BOARD_WIDTH];
	int angel_x;
	int angel_y;
	int spent;

	void throw_exception() const {
		invalid_movement e;
		throw e;
	}

	void move_seat(int original_y, int original_x,
	               int offset_y, int offset_x) {
		board[original_y][original_x] = ' ';
		board[original_y + offset_y][original_x + offset_x] = '$';
	}

public:	
	int getx() const {
		return angel_x;
	}

	int gety() const {
		return angel_y;
	}

	int get_spent() const {
		return spent;
	}

	bool finish() const {
		return (angel_x == BOARD_WIDTH - 2 && angel_y == 1);
	}

	snapshot(const snapshot * x = 0,
	         int offset_y = 0, int offset_x = 0) {
		this->parent = x;

		if (!x) {
			spent = 0;
			return;
		}

		for (int i = 0; i < BOARD_HEIGHT; ++i)
			for (int j = 0; j < BOARD_WIDTH; ++j)
				board[i][j] = x->board[i][j];
		angel_y = x->angel_y + offset_y;
		angel_x = x->angel_x + offset_x;
		board[x->angel_y][x->angel_x] = ' ';
		board[angel_y][angel_x] = '*';
		spent = x->spent + 1;
	}

	snapshot * move_up() const {
		if (board[angel_y - 1][angel_x] != ' ')
			throw_exception();

		return new snapshot(this, -1, 0);
	}

	snapshot * move_down() const {
		if (board[angel_y + 1][angel_x] != ' ')
			throw_exception();

		return new snapshot(this, 1, 0);
	}

	snapshot * move_left() const {
		if (board[angel_y][angel_x - 1] != ' ')
			throw_exception();

		return new snapshot(this, 0, -1);
	}

	snapshot * move_right() const {
		if (board[angel_y][angel_x + 1] != ' ')
			throw_exception();

		return new snapshot(this, 0, 1);
	}

	snapshot * pull_up() const {
		if (board[angel_y + 1][angel_x] != '$')
			throw_exception();

		snapshot * result = move_up();
		result->move_seat(angel_y + 1, angel_x, -1, 0);
		return result;
	}

	snapshot * pull_down() const {
		if (board[angel_y - 1][angel_x] != '$')
			throw_exception();

		snapshot * result = move_down();
		result->move_seat(angel_y - 1, angel_x, 1, 0);
		return result;
	}

	snapshot * pull_left() const {
		if (board[angel_y][angel_x + 1] != '$')
			throw_exception();

		snapshot * result = move_left();
		result->move_seat(angel_y, angel_x + 1, 0, -1);
		return result;
	}

	snapshot * pull_right() const {
		if (board[angel_y][angel_x - 1] != '$')
			throw_exception();

		snapshot * result = move_right();
		result->move_seat(angel_y, angel_x - 1, 0, 1);
		return result;
	}
	
	void read_snapshot() {
		for (int i = 0; i < BOARD_HEIGHT; ++i) {
			string temp;
			getline(cin, temp);

			for (int j = 0; j < BOARD_WIDTH; ++j) {
				board[i][j] = temp[j];
				if (board[i][j] == '*') {
					angel_y = i;
					angel_x = j;
				}
			}
		}
	}

	void print_snapshot() const {
		for (int i = 0; i < BOARD_HEIGHT; ++i) {
			for (int j = 0; j < BOARD_WIDTH; ++j)
				cout << board[i][j];
			cout << endl;
		}
		cout << endl;
	}

	void print_path() const {
		if (parent)
			parent->print_path();
		print_snapshot();
	}

	bool operator < (const snapshot &other) const {
		if (angel_x != other.angel_x)
			return angel_x < other.angel_x;

		if (angel_y != other.angel_y)
			return angel_y < other.angel_y;

		for (int i = 0; i < BOARD_HEIGHT; ++i) {
			for (int j = 0; j < BOARD_WIDTH; ++j) {
				if (board[i][j] != other.board[i][j])
					return board[i][j] < other.board[i][j];
			}
		}

		return false;
	}
};

class longer_later {
public:
	bool operator() (const snapshot * x, const snapshot * y) {
		int x_distance = x->get_spent() + abs(1 - x->gety()) +
		                 abs(BOARD_WIDTH - 2 - x->getx());
		int y_distance = y->get_spent() + abs(1 - y->gety()) +
		                 abs(BOARD_WIDTH - 2 - y->getx());
		return (x_distance > y_distance);
	}
};

void consider_and_print(snapshot * x) {
	priority_queue< snapshot *, vector <snapshot *>, longer_later > fringe;
	set< snapshot > considered;

	fringe.push(x);
	while (!fringe.empty()) {
		string temp;
		snapshot * ptr = fringe.top();
		fringe.pop();
		// ptr->print_snapshot();

		if (ptr->finish()) {
			ptr->print_path();
			return;
		}

		// Don't consider the same thing twice. This would lead to
		// dead looping.
		snapshot current = *ptr;
		if (considered.find(current) != considered.end())
			continue;
		considered.insert(current);

		try {
			fringe.push(ptr->move_up());
		} catch (invalid_movement e) {
		//	cerr << "Move up impossible" << endl;
		}

		try {
			fringe.push(ptr->move_right());
		} catch (invalid_movement e) {
		//	cerr << "Move right impossible" << endl;
		}

		try {
			fringe.push(ptr->move_down());
		} catch (invalid_movement e) {
		//	cerr << "Move down impossible" << endl;
		}

		try {
			fringe.push(ptr->move_left());
		} catch (invalid_movement e) {
		//	cerr << "Move left impossible" << endl;
		}

		try {
			fringe.push(ptr->pull_down());
		} catch (invalid_movement e) {
		//	cerr << "Pull down impossible" << endl;
		}

		try {
			fringe.push(ptr->pull_left());
		} catch (invalid_movement e) {
		//	cerr << "Pull left impossible" << endl;
		}

		try {
			fringe.push(ptr->pull_right());
		} catch (invalid_movement e) {
		//	cerr << "Pull right impossible" << endl;
		}

		try {
			fringe.push(ptr->pull_up());
		} catch (invalid_movement e) {
		//	cerr << "Pull up impossible" << endl;
		}

		// getline(cin, temp);
	}
}

int main() {
	snapshot problem;
	problem.read_snapshot();
	consider_and_print(&problem);
	return 0;
}

